@@ -10,6 +10,7 @@ list_drivers <-
       "Vertica Database",
       "duckdb_connection",
       "MySQLConnection",
-      "SQLiteConnection"
+      "SQLiteConnection",
+      "Microsoft SQL Server"
     )
   }
